format_in

Function format_in 

pub fn format_in(
    locale_name: &str,
    key: &str,
    args: &[(String, FArg)],
) -> String
Resolve key: app bundle for the locale, then app-default, then the built-in core catalog for the locale, then core English. en-XA resolves against the default and accents the result. Signal args are tracked reads.

Day API ↩ Guides· daybrite.dev